@@ -1,7 +1,7 @@
 package App::yamlsel;
 
-our $DATE = '2016-08-27'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-09-01'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,7 +24,7 @@ sub _decode_yaml {
 
 $SPEC{yamlsel} = {
     v => 1.1,
-    summary => 'Select YAML elements using CSS selector syntax',
+    summary => 'Select YAML elements using CSel (CSS-selector-like) syntax',
     args => {
         %App::CSelUtils::foosel_common_args,
         %App::CSelUtils::foosel_struct_action_args,
@@ -56,8 +56,9 @@ sub yamlsel {
     my @matches = Data::CSel::csel(
         {class_prefixes=>['Data::CSel::WrapStruct']}, $expr, $tree);
 
-    # skip root node itself
-    @matches = grep { refaddr($_) ne refaddr($tree) } @matches;
+    # skip root node itself to avoid duplication
+    @matches = grep { refaddr($_) ne refaddr($tree) } @matches
+        unless @matches <= 1;
 
     for my $action (@$actions) {
         if ($action eq 'print') {
@@ -72,7 +73,7 @@ sub yamlsel {
 }
 
 1;
-# ABSTRACT: Select YAML elements using CSS selector syntax
+# ABSTRACT: Select YAML elements using CSel (CSS-selector-like) syntax
 
 __END__
 
@@ -82,11 +83,11 @@ __END__
 
 =head1 NAME
 
-App::yamlsel - Select YAML elements using CSS selector syntax
+App::yamlsel - Select YAML elements using CSel (CSS-selector-like) syntax
 
 =head1 VERSION
 
-This document describes version 0.001 of App::yamlsel (from Perl distribution App-yamlsel), released on 2016-08-27.
+This document describes version 0.002 of App::yamlsel (from Perl distribution App-yamlsel), released on 2016-09-01.
 
 =head1 SYNOPSIS
 
@@ -95,7 +96,7 @@ This document describes version 0.001 of App::yamlsel (from Perl distribution Ap
 
 =head2 yamlsel(%args) -> [status, msg, result, meta]
 
-Select YAML elements using CSS selector syntax.
+Select YAML elements using CSel (CSS-selector-like) syntax.
 
 This function is not exported.
 
